<?php
if ( ! class_exists( 'NISHIKI_PRO_SPDB_REST_API' ) ) {
	/**
	 * Rest API 設定
	 */
	class NISHIKI_PRO_SPDB_REST_API {
		/**
		 * 初期設定
		 */
		public function __construct() {
			add_action( 'rest_api_init', array( $this, 'create_endpoint' ) );
		}

		/**
		 * エンドポイント作成
		 *
		 * @return void
		 */
		public function create_endpoint() {
			register_rest_route(
				'customizer/v1',
				'/settings',
				array(
					array(
						'methods'             => 'GET',
						'callback'            => array( $this, 'callback' ),
						'permission_callback' => array( $this, 'rest_permission' ),
						// 'permission_callback' => function() { return current_user_can( 'edit_others_posts' ); }
					),
					array(
						'methods'             => 'PUT',
						'callback'            => array( $this, 'update_callback' ),
						'permission_callback' => array( $this, 'rest_permission' ),
					),
				)
			);
		}

		/**
		 * コールバック
		 *
		 * @return object
		 */
		public function callback() {

			// TopPage
			$data['topPage'] = get_option( 'show_on_front' );

			// Option
			$toc_array = array(
				'id'      => 'toc',
				'name'    => '目次',
				'checked' => get_theme_mod( 'setting_nishiki_pro_toc_display', true ),
			);

			$scroll_page_top_array = array(
				'id'      => 'pageTop',
				'name'    => 'ページ上部に戻るボタン',
				'checked' => get_theme_mod( 'setting_nishiki_pro_footer_scroll_page_top_button_enable', false ),
			);

			// カラー01
			$color_01_01 = get_theme_mod( 'setting_header_background_color' );
			$color_01_02 = '#' . get_theme_mod( 'header_textcolor', '#ffffff' );
			
			// カラー02
			$color_02_01 = get_theme_mod( 'setting_site_accent_color_01' );
			$color_02_02 = get_theme_mod( 'setting_site_accent_color_02' );
			
			// カラー03
			$color_03_01 = get_theme_mod( 'setting_site_main_color_01' );
			$color_03_02 = get_theme_mod( 'setting_site_main_color_02' );
			
			// カラー04
			$color_04_01 = get_theme_mod( 'setting_site_main_color' );
			$color_04_02 = get_theme_mod( 'setting_site_sub_color' );

			// カラー05
			$color_05_01 = get_theme_mod( 'setting_' . NISHIKI_PRO_PREFIX_FOOTER . '_nav_background_color' );
			$color_05_02 = get_theme_mod( 'setting_' . NISHIKI_PRO_PREFIX_FOOTER . '_nav_text_color' );

			// Color List
			$color_list = array(
				array( 'color01' => $color_01_01, 'color02' => $color_01_02 ),
				array( 'color01' => $color_02_01, 'color02' => $color_02_02 ),
				array( 'color01' => $color_03_01, 'color02' => $color_03_02 ),
				array( 'color01' => $color_04_01, 'color02' => $color_04_02 ),
				array( 'color01' => $color_05_01, 'color02' => $color_05_02 )
			);

			$data['option'][] = $toc_array;
			$data['option'][] = $scroll_page_top_array;
			$data['colorList'] = $color_list;

			return new WP_REST_Response( $data, 200 );
		}

		/**
		 * コールバック（アップデート）
		 *
		 * @param array $req リクエスト
		 * @return object
		 */
		public function update_callback( $req ) {
			if ( ! isset( $req ) ) {
				return false;
			}

			$data = array();

			// トップページ
			if ( isset( $req['top_page'] ) ) {
				update_option( 'show_on_front', $req['top_page'] );
			}

			// カラー
			if ( isset( $req['color_list'] ) && 'custom' === $req['color_setting'] ) {
				$data['color_list'] = $req['color_list'];

				// カラー1 ヘッダー
				set_theme_mod( 'setting_header_background_color', $req['color_list'][0]['color01'] );
				set_theme_mod( 'header_textcolor', substr( $req['color_list'][0]['color02'], 1 ) );

				// カラー1 フッター
				set_theme_mod( 'setting_footer_background_color', '#ffffff' );
				set_theme_mod( 'setting_footer_widget_text_color', '#222222' );
				set_theme_mod( 'setting_footer_widget_link_color', $req['color_list'][3]['color01'] );
				set_theme_mod( 'setting_footer_text_color', '#222222' );
				set_theme_mod( 'setting_footer_link_color', $req['color_list'][3]['color01'] );

				// カラー1 ソーシャルアカウント
				set_theme_mod( 'setting_nishiki_pro_social_background_color', $req['color_list'][0]['color01'] );
				set_theme_mod( 'setting_nishiki_pro_social_text_color', $req['color_list'][0]['color02'] );

				// カラー2 タイトル
				set_theme_mod( 'setting_post_title_background_color', $req['color_list'][1]['color01'] );
				set_theme_mod( 'setting_post_title_text_color', $req['color_list'][1]['color02'] );
				set_theme_mod( 'setting_page_title_background_color', $req['color_list'][1]['color01'] );
				set_theme_mod( 'setting_page_title_text_color', $req['color_list'][1]['color02'] );
				set_theme_mod( 'setting_archive_title_background_color', $req['color_list'][1]['color01'] );
				set_theme_mod( 'setting_archive_title_text_color', $req['color_list'][1]['color02'] );

				// カラー2 メインカラー
				set_theme_mod( 'setting_site_main_color_01', $req['color_list'][2]['color01'] );
				set_theme_mod( 'setting_site_main_color_02', $req['color_list'][2]['color02'] );

				// カラー3 アクセントカラー
				set_theme_mod( 'setting_site_accent_color_01', $req['color_list'][1]['color01'] );
				set_theme_mod( 'setting_site_accent_color_02', $req['color_list'][1]['color02'] );

				// カラー4 パンくずリンクカラー
				set_theme_mod( 'setting_nishiki_pro_breadcrumbs_link_color', $req['color_list'][3]['color01'] );
				set_theme_mod( 'setting_nishiki_pro_breadcrumbs_link_hover_color', $req['color_list'][3]['color01'] );

				// カラー4 テキストリンクカラー
				set_theme_mod( 'setting_site_main_color', $req['color_list'][3]['color01'] );
				set_theme_mod( 'setting_site_sub_color', $req['color_list'][3]['color01'] );

				// カラー5 フッターメニュー
				set_theme_mod( 'setting_' . NISHIKI_PRO_PREFIX_FOOTER . '_nav_background_color', $req['color_list'][4]['color01'] );
				set_theme_mod( 'setting_' . NISHIKI_PRO_PREFIX_FOOTER . '_nav_background_hover_color', $req['color_list'][4]['color01'] );
				set_theme_mod( 'setting_' . NISHIKI_PRO_PREFIX_FOOTER . '_nav_text_color', $req['color_list'][4]['color02'] );
				set_theme_mod( 'setting_' . NISHIKI_PRO_PREFIX_FOOTER . '_nav_text_hover_color', $req['color_list'][4]['color02'] );

				// set_theme_mod( 'setting_site_background_color', $req['base_color'] );

			}

			// オプション ページ上部へ戻る
			if ( isset( $req['option']['pageTop'] ) ) {
				set_theme_mod( 'setting_' . NISHIKI_PRO_PREFIX_FOOTER . '_scroll_page_top_button_enable', $req['option']['pageTop'] );
			}

			// オプション 目次
			if ( isset( $req['option']['toc'] ) ) {
				set_theme_mod( 'setting_' . NISHIKI_PRO_PREFIX_TOC . '_display', $req['option']['toc'] );
				set_theme_mod( 'setting_' . NISHIKI_PRO_PREFIX_TOC . '_fixed_display', $req['option']['toc'] );
			}

			// パンくずリスト

			return new WP_REST_Response( $data, 200 );
		}

		/**
		 * アクセスできる権限
		 *
		 * @return boolean
		 */
		public function rest_permission() {
			return current_user_can( 'manage_options' );
		}
	}

	new NISHIKI_PRO_SPDB_REST_API();
}
